<?php
// $Id: template.php,v 1.2 2010/07/06 18:09:10 mojah Exp $

require_once('theme-settings.php');

/**
 * Initialize theme settings.
 */
global $theme_key;
opengrid_initialize_theme_settings($theme_key);

// Auto-rebuild the theme registry during theme development.
if (theme_get_setting('opengrid_rebuild_registry')) {
  drupal_rebuild_theme_registry();
}

if(theme_get_setting('css_switch') == 0){
  drupal_add_css(drupal_get_path('theme', 'opengrid') .'/css/960_16.css', 'theme', 'screen');
}

if(theme_get_setting('scroll_to_top') == 1){
  drupal_add_js(drupal_get_path('theme', 'opengrid') .'/js/scrolToTop.js');
}

/**
 * Implements HOOK_theme().
 */
function opengrid_theme(&$existing, $type, $theme, $path) {
  if (!db_is_active()) {
    return array();
  }
  $items = array();
  $items['containers_settings_table'] = array(
    'arguments' => array('form')
  );
  $items['grids_settings_table'] = array(
    'arguments' => array('form')
  );

  return $items;
}

function opengrid_preprocess(&$vars, $hook) {
  $vars['my_layout'] = 'no_sidebars';
  if (block_list('left') && block_list('right')){
    $vars['my_layout'] = 'both_sidebars';
  }
  if (block_list('left') && !block_list('right')){
    $vars['my_layout'] = 'first_sidebar';
  }
  if (!block_list('left') && block_list('right')){
    $vars['my_layout'] = 'second_sidebar';
  }
}

function opengrid_preprocess_page(&$vars) {
  
  
  //copy the content in the sidebars variables to the newsidebars variables 
  $vars['first_sidebar'] = $vars['left'];
  $vars['secon_sidebar'] = $vars['right'];
    
  // adds classes to primary links configured in theme settings
  if (theme_get_setting('navigation_classes') == 'none' && theme_get_setting('navigation_extras') != '') {
    $vars['main_navigation_classes'] .= ' '. theme_get_setting('navigation_extras');
  }
  if (theme_get_setting('navigation_classes') != 'none') {
    $vars['main_navigation_classes'] .= ' '. theme_get_setting('navigation_classes');
  } 
  if (theme_get_setting('navigation_extras') != '') {
    $vars['main_navigation_classes'] .= ' '. theme_get_setting('navigation_extras');
  }

  $vars['primary_links'] = theme('links',$vars['primary_links']);
  $vars['secondary_links'] = theme('links',$vars['secondary_links']);
  //rewrite primary links for dropdown support  
  if(theme_get_setting('primary_dropdown') == 1){
    $vars['primary_links'] = menu_tree(variable_get('menu_primary_links_source', 'primary-links'));
  }

  if (is_file(drupal_get_path('theme', 'opengrid') . '/opengrid_grid_assembler.inc')) {
    include('opengrid_grid_assembler.inc');
  }
  if ($vars['right'] && $vars['left']) {
    $sal = layout_grid_assembler('both_sidebars_layout');
  }
  if($vars['right'] && !$vars['left']) {
    $sal = layout_grid_assembler('second_sidebar_layout');
    $vars['body_classes'] = str_replace('sidebar-right', 'second-sidebar',$vars['body_classes']);
  }
  if (!$vars['right'] && $vars['left']) {
    $sal = layout_grid_assembler('first_sidebar_layout');
    $vars['body_classes'] = str_replace('sidebar-left', 'first-sidebar',$vars['body_classes']);
  }
  if (!$vars['right'] && !$vars['left']) {
    $sal = layout_grid_assembler('no_sidebars_layout');
  }
  if (is_array($sal)) {
    $vars = array_merge($vars, $sal);
  }
  // Add liquid-layout class to the body
  if (theme_get_setting('css_switch') == 1) {
    $vars['body_classes'] .= ' liquid-layout';
  }
  if (theme_get_setting('scroll_to_top') == 1) {
    $vars['scroll_to_top'] = t('Back to Top');
  }
  //body classes adjustments
  $vars['body_classes'] = str_replace('not-front','',$vars['body_classes']);
  if(arg(0) == 'node' && arg(1) == 'add'){
    $vars['body_classes'] .= ' node-add-section';   
  }
  if(arg(0) == 'node' && arg(2) == 'edit'){
    $vars['body_classes'] .= ' node-edit-section';   
  }  

}

function opengrid_preprocess_node(&$vars) {
  $vars['node_classes'] = $vars['page'] ? 'node' : 'teaser';
}

function opengrid_preprocess_block(&$vars){
  $block = $vars['block'];

  $block_id = 'block-'. $block->module .'-'. $block->delta;
  $vars['block_id'] = $block_id;
  $vars['block_classes'] .= ' block block-'. $block->module;

  if (module_exists('opengrid_ui')) {
    $theme = variable_get('theme_default','none');
    $settings = variable_get('theme_'. $theme .'_settings', array());
    $layout = $vars['my_layout'];
    $block_grid_classes = $settings[$layout .'_layout'][$block_id]['grid'];
    if (is_array($block_grid_classes)) {
      foreach ($block_grid_classes as $key => $value) {
        if ($value != '0') {
          $vars['block_classes'] .= ' '. $value;
        }
      }
    }
  }
}

/**
 * Returns a table to configure container settings.
 */
function opengrid_containers_settings_table(&$form){
  $rows = array();
  $header = array('', t('Columns'),t('Extras'));

  foreach(element_children($form) as $key) {
    $name = $form[$key]['grid']['#title'];
    $form[$key]['grid']['#title'] = '';
    $form[$key]['extras']['#title'] = '';
    $row = array(
      $name,
      drupal_render($form[$key]['grid']),
      drupal_render($form[$key]['extras']),
    );
    $rows[] = $row;
  }

  $output = theme('table', $header, $rows);
  return $output;
}

/**
 *  Returns a table to configure grid settings.
 */
function opengrid_grids_settings_table(&$form){
  $rows = array();
  $header = array (
    t('Region'), 
    t('Width'),
    t('Prefix'),
    t('Suffix'),
    t('Push'),
    t('Pull'),
    t('Alpha'),
    t('Omega'),
    t('Extras'),
    //t('Container'),
  );

  foreach (element_children($form) as $key) {
    $name = $form[$key]['grid']['#title'];

    $form[$key]['grid']['#title'] = '';
    $container = t('No container');
    if ($key != 'main_grid' && $key != 'first_sidebar_grid' && $key != 'second_sidebar_grid') {
      $container = drupal_render($form[$key]['container']);
    }
    $row = array(
      $name,
      drupal_render($form[$key]['grid']),
      drupal_render($form[$key]['prefix']),
      drupal_render($form[$key]['suffix']),
      drupal_render($form[$key]['push']),
      drupal_render($form[$key]['pull']),
      drupal_render($form[$key]['alpha']),
      drupal_render($form[$key]['omega']),
      drupal_render($form[$key]['extras']),
      //$container,
    );
    $rows[] = $row;
  }

  $output = theme('table', $header, $rows);
  return $output;
}

/**
 * File element override
 * Sets form file input max width
 */
function opengrid_file($element) {
  $element['#size'] = ($element['#size'] > 40) ? 40 : $element['#size'];
  return theme_file($element);
}

/*
*  Load extra files for superfish dropdowns 
*/
if(theme_get_setting('primary_dropdown') == 1){
  drupal_add_js(drupal_get_path('theme','opengrid').'/js/superfish/superfish.js');
  drupal_add_js(drupal_get_path('theme','opengrid').'/js/superfish/superfish_config.js');
  drupal_add_css(drupal_get_path('theme','opengrid').'/js/superfish/superfish.css');
  drupal_add_css(drupal_get_path('theme','opengrid').'/js/superfish/superfish-navbar.css');
}

function opengrid_node_form($form) {
  //fixed position forsubmit buttons
  if (theme_get_setting('fixed_buttons') == 1) {
    $form['buttons']['#prefix'] = '<div class="buttons-wrapper">';
    $form['buttons']['#suffix'] = '</div>'; 

  }
  $form['buttons']['#weight'] = 50;
  return drupal_render($form);
}
